#ifndef DECAYFORMAT_H
#define DECAYFORMAT_H
#include <ParticleCodes.h>
#include <flavoursoft.h>
#include <linalg.h>
#include <fstream>
#include <spice.h>

class DecayCalc;

//DecayFormat class
//Used to output the flavor-violating model parameters to an intermediate file
//with pseudo-Herwig format
class DecayFormat{
 private:

  FlavourMssmSoftsusy* model;  //Pointer to the MssmSoftsusy object from which 
                               //output will be derived
  DecayCalc* decays;    //Pointer to the DecayCalc object used to calculate
                        //FV decay widths
  ofstream fout;        //ofstream object used for output.  The output file
                        //is defined in the constructor

  //Method used to define to find the PDG code for a given type of particle 
  //of a given generation
  int PDGCode(particletype particle,int particleindex);

  //Output the a particle code and mass
  void OutputParticle(int particleId,double mass);

  //Output a list of particle masses
  void OutputParticleData();

  //Output the particle decays
  void OutputDecayTable();

  //Output the SUSY parameters contained at the end of a Herwig file
  void OutputSusyParams();

 public:

  //Constructor
  DecayFormat(FlavourMssmSoftsusy *r);

  //'get' methods
  ofstream& getFout() {return fout;}
  FlavourMssmSoftsusy* getModel() {return model;}
  DecayCalc* getDecays() {return decays;}

  //Output a two-body decay
  void TwoBodyDecay(double width,particletype parent,int parentindex,
                    particletype daughter1,int daughter1index,
                    particletype daughter2,int daughter2index);

  //Output a three-body decay
  void ThreeBodyDecay(double width,particletype parent,int parentindex,
                      particletype daughter1,int daughter1index,
                      particletype daughter2,int daughter2index,
                      particletype daughter3,int daughter3index);

  //Control method to output the entire intermediate file
  void OutputIntermediateFile();
};

#endif
