#ifndef SPICE_H
#define SPICE_H

// Standard C++ libraries
#include <iostream>
#include <sstream>
#include <string>

// SOFTSUSY header files
#include <def.h>
#include <flavoursoft.h>
#include <linalg.h>
#include <lowe.h>
#include <mycomplex.h>
#include <numerics.h>
#include <rge.h>
#include <softsusy.h>
#include <softpars.h>
#include <susy.h>
#include <twoloophiggs.h>
#include <utils.h>

using namespace std;

// Incorrect command line input: gives advice on how to call SPICE
// properly
void errorCall();

// Method to take input from script file
// Default script file name is GaugeGravityInit
void readParams(char* fname, DoubleVector &inParams);

// Method to generate arbitrary coefficients 
double* O1params(long k = -532901, double sigma = 1.0);

// Modified GMSB, AMSB, mSUGRA boundary conditions to include
// used-defined flavor contributions to slepton and sneutrino masses
void gaugegravityBcs(MssmSoftsusy &m, 
		     const DoubleVector &inputParameters);
void anomalygravityBcs(MssmSoftsusy &m, 
		       const DoubleVector &inputParameters);
void sugragravityBcs(MssmSoftsusy &m, 
		     const DoubleVector &inputParameters);

// Implements a specific model (U(1) horizontal symmetry(ies)) of flavor
// contributions to slepton and sneutrino masses. gravityBcs calls
// BuildLeptonicMatrices, which writes LepYukawa, SLepXL, and SLepXR
// appropriately
// CITE: Feng, et al., arXiv:0712.0674 [hep-ph]
void gravityBcs(MssmSoftsusy &m, const DoubleVector &inputParameters);
void BuildLeptonicMatrices(const DoubleVector &inputParameters, 
                           DoubleMatrix &LepYukawa, DoubleMatrix &SLepXL,
                           DoubleMatrix &SLepXR);

#endif
